@@ -291,6 +291,8 @@ class SSHClient(object):
             scp_cmd = [
                 "scp", "-r",
                 "-P", str(ssh_port),  # 指定SSH端口
+                "-o", "StrictHostKeyChecking=no",  # 忽略主机密钥检查
+                "-o", "UserKnownHostsFile=/dev/null",  # 不保存主机密钥（可选，避免污染known_hosts）
                 str(local_path),  # 本地目录
                 remote_scp_path  # 远端目标路径
             ]
